package ch.ethz.ssh2.channel;

import java.io.IOException;
import java.io.OutputStream;

/**
 * ChannelOutputStream.
 * 
 * @author Christian Plattner, plattner@inf.ethz.ch
 * @version $Id: ChannelOutputStream.java,v 1.2 2005/06/13 10:51:52 cplattne Exp $
 */
public final class ChannelOutputStream extends OutputStream
{
	Channel c;
	byte[] buffer = new byte[Channel.CHANNEL_BUFFER_SIZE];
	int pos = 0;

	boolean isClosed = false;
	
	ChannelOutputStream(Channel c)
	{
		this.c = c;
	}

	public void write(int b) throws IOException
	{
		if (isClosed)
			throw new IOException("This OutputStream is closed.");
		
		if (pos == buffer.length) flush();
		buffer[pos++] = (byte) b;
	}

	public void close() throws IOException
	{
		if (isClosed == false)
		{
			isClosed = true;
			c.cm.sendEOF(c);
		}
	}

	public void flush() throws IOException
	{
		if (isClosed)
			throw new IOException("This OutputStream is closed.");
		
		if (pos > 0) c.cm.sendData(c, buffer, 0, pos);
		pos = 0;
	}

	public void write(byte[] b, int off, int len) throws IOException
	{
		if (isClosed)
			throw new IOException("This OutputStream is closed.");
		
		while (len > 0)
		{
			int avail = buffer.length - pos;
			int thislen = (avail >= len) ? len : avail;
			
			System.arraycopy(b, off, buffer, pos, thislen);
			
			pos += thislen;
			len -= thislen;
			off += thislen;
			
			if (pos == buffer.length)
				flush();
		}	
	}

	public void write(byte[] b) throws IOException
	{
		if (isClosed)
			throw new IOException("This OutputStream is closed.");
		
		write(b, 0, b.length);
	}
}
